'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def create_replication_job(serverId=None, seedReplicationTime=None, frequency=None, licenseType=None, roleName=None, description=None):
    """
    The CreateReplicationJob API is used to create a ReplicationJob to replicate a server on AWS. Call this API to first create a ReplicationJob, which will then schedule periodic ReplicationRuns to replicate your server to AWS. Each ReplicationRun will result in the creation of an AWS AMI.
    See also: AWS API Documentation
    
    
    :example: response = client.create_replication_job(
        serverId='string',
        seedReplicationTime=datetime(2015, 1, 1),
        frequency=123,
        licenseType='AWS'|'BYOL',
        roleName='string',
        description='string'
    )
    
    
    :type serverId: string
    :param serverId: [REQUIRED] Unique Identifier for a server

    :type seedReplicationTime: datetime
    :param seedReplicationTime: [REQUIRED] Timestamp of an operation

    :type frequency: integer
    :param frequency: [REQUIRED] Interval between Replication Runs. This value is specified in hours, and represents the time between consecutive Replication Runs.

    :type licenseType: string
    :param licenseType: The license type to be used for the Amazon Machine Image (AMI) created after a successful ReplicationRun.

    :type roleName: string
    :param roleName: Name of service role in customer's account to be used by SMS service.

    :type description: string
    :param description: The description for a Replication Job/Run.

    :rtype: dict
    :return: {
        'replicationJobId': 'string'
    }
    
    
    :returns: 
    (dict) --
    replicationJobId (string) -- The unique identifier for a Replication Job.
    
    
    
    """
    pass

def delete_replication_job(replicationJobId=None):
    """
    The DeleteReplicationJob API is used to delete a ReplicationJob, resulting in no further ReplicationRuns. This will delete the contents of the S3 bucket used to store SMS artifacts, but will not delete any AMIs created by the SMS service.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_replication_job(
        replicationJobId='string'
    )
    
    
    :type replicationJobId: string
    :param replicationJobId: [REQUIRED] The unique identifier for a Replication Job.

    :rtype: dict
    :return: {}
    
    
    """
    pass

def delete_server_catalog():
    """
    The DeleteServerCatalog API clears all servers from your server catalog. This means that these servers will no longer be accessible to the Server Migration Service.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_server_catalog()
    
    
    :rtype: dict
    :return: {}
    
    
    """
    pass

def disassociate_connector(connectorId=None):
    """
    The DisassociateConnector API will disassociate a connector from the Server Migration Service, rendering it unavailable to support replication jobs.
    See also: AWS API Documentation
    
    
    :example: response = client.disassociate_connector(
        connectorId='string'
    )
    
    
    :type connectorId: string
    :param connectorId: [REQUIRED] Unique Identifier for Connector

    :rtype: dict
    :return: {}
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_connectors(nextToken=None, maxResults=None):
    """
    The GetConnectors API returns a list of connectors that are registered with the Server Migration Service.
    See also: AWS API Documentation
    
    
    :example: response = client.get_connectors(
        nextToken='string',
        maxResults=123
    )
    
    
    :type nextToken: string
    :param nextToken: Pagination token to pass as input to API call

    :type maxResults: integer
    :param maxResults: The maximum number of results to return in one API call. If left empty, this will default to 50.

    :rtype: dict
    :return: {
        'connectorList': [
            {
                'connectorId': 'string',
                'version': 'string',
                'status': 'HEALTHY'|'UNHEALTHY',
                'capabilityList': [
                    'VSPHERE',
                ],
                'vmManagerName': 'string',
                'vmManagerType': 'VSPHERE',
                'vmManagerId': 'string',
                'ipAddress': 'string',
                'macAddress': 'string',
                'associatedOn': datetime(2015, 1, 1)
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (dict) --
    connectorList (list) -- List of connectors
    (dict) -- Object representing a Connector
    connectorId (string) -- Unique Identifier for Connector
    version (string) -- Connector version string
    status (string) -- Status of on-premise Connector
    capabilityList (list) -- List of Connector Capabilities
    (string) -- Capabilities for a Connector
    
    
    vmManagerName (string) -- VM Manager Name
    vmManagerType (string) -- VM Management Product
    vmManagerId (string) -- Unique Identifier for VM Manager
    ipAddress (string) -- Internet Protocol (IP) Address
    macAddress (string) -- Hardware (MAC) address
    associatedOn (datetime) -- Timestamp of an operation
    
    
    
    
    nextToken (string) -- Pagination token to pass as input to API call
    
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_replication_jobs(replicationJobId=None, nextToken=None, maxResults=None):
    """
    The GetReplicationJobs API will return all of your ReplicationJobs and their details. This API returns a paginated list, that may be consecutively called with nextToken to retrieve all ReplicationJobs.
    See also: AWS API Documentation
    
    
    :example: response = client.get_replication_jobs(
        replicationJobId='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type replicationJobId: string
    :param replicationJobId: The unique identifier for a Replication Job.

    :type nextToken: string
    :param nextToken: Pagination token to pass as input to API call

    :type maxResults: integer
    :param maxResults: The maximum number of results to return in one API call. If left empty, this will default to 50.

    :rtype: dict
    :return: {
        'replicationJobList': [
            {
                'replicationJobId': 'string',
                'serverId': 'string',
                'serverType': 'VIRTUAL_MACHINE',
                'vmServer': {
                    'vmServerAddress': {
                        'vmManagerId': 'string',
                        'vmId': 'string'
                    },
                    'vmName': 'string',
                    'vmManagerName': 'string',
                    'vmManagerType': 'VSPHERE',
                    'vmPath': 'string'
                },
                'seedReplicationTime': datetime(2015, 1, 1),
                'frequency': 123,
                'nextReplicationRunStartTime': datetime(2015, 1, 1),
                'licenseType': 'AWS'|'BYOL',
                'roleName': 'string',
                'latestAmiId': 'string',
                'state': 'PENDING'|'ACTIVE'|'FAILED'|'DELETING'|'DELETED',
                'statusMessage': 'string',
                'description': 'string',
                'replicationRunList': [
                    {
                        'replicationRunId': 'string',
                        'state': 'PENDING'|'MISSED'|'ACTIVE'|'FAILED'|'COMPLETED'|'DELETING'|'DELETED',
                        'type': 'ON_DEMAND'|'AUTOMATIC',
                        'statusMessage': 'string',
                        'amiId': 'string',
                        'scheduledStartTime': datetime(2015, 1, 1),
                        'completedTime': datetime(2015, 1, 1),
                        'description': 'string'
                    },
                ]
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (dict) --
    replicationJobList (list) -- List of Replication Jobs
    (dict) -- Object representing a Replication Job
    replicationJobId (string) -- The unique identifier for a Replication Job.
    serverId (string) -- Unique Identifier for a server
    serverType (string) -- Type of server.
    vmServer (dict) -- Object representing a VM server
    vmServerAddress (dict) -- Object representing a server's location
    vmManagerId (string) -- Unique Identifier for VM Manager
    vmId (string) -- Unique Identifier for a VM
    
    
    vmName (string) -- Name of Virtual Machine
    vmManagerName (string) -- VM Manager Name
    vmManagerType (string) -- VM Management Product
    vmPath (string) -- Path to VM
    
    
    seedReplicationTime (datetime) -- Timestamp of an operation
    frequency (integer) -- Interval between Replication Runs. This value is specified in hours, and represents the time between consecutive Replication Runs.
    nextReplicationRunStartTime (datetime) -- Timestamp of an operation
    licenseType (string) -- The license type to be used for the Amazon Machine Image (AMI) created after a successful ReplicationRun.
    roleName (string) -- Name of service role in customer's account to be used by SMS service.
    latestAmiId (string) -- The AMI id for the image resulting from a Replication Run.
    state (string) -- Current state of Replication Job
    statusMessage (string) -- String describing current status of Replication Job
    description (string) -- The description for a Replication Job/Run.
    replicationRunList (list) -- List of Replication Runs
    (dict) -- Object representing a Replication Run
    replicationRunId (string) -- The unique identifier for a Replication Run.
    state (string) -- Current state of Replication Run
    type (string) -- Type of Replication Run
    statusMessage (string) -- String describing current status of Replication Run
    amiId (string) -- The AMI id for the image resulting from a Replication Run.
    scheduledStartTime (datetime) -- Timestamp of an operation
    completedTime (datetime) -- Timestamp of an operation
    description (string) -- The description for a Replication Job/Run.
    
    
    
    
    
    
    
    
    nextToken (string) -- Pagination token to pass as input to API call
    
    
    
    """
    pass

def get_replication_runs(replicationJobId=None, nextToken=None, maxResults=None):
    """
    The GetReplicationRuns API will return all ReplicationRuns for a given ReplicationJob. This API returns a paginated list, that may be consecutively called with nextToken to retrieve all ReplicationRuns for a ReplicationJob.
    See also: AWS API Documentation
    
    
    :example: response = client.get_replication_runs(
        replicationJobId='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type replicationJobId: string
    :param replicationJobId: [REQUIRED] The unique identifier for a Replication Job.

    :type nextToken: string
    :param nextToken: Pagination token to pass as input to API call

    :type maxResults: integer
    :param maxResults: The maximum number of results to return in one API call. If left empty, this will default to 50.

    :rtype: dict
    :return: {
        'replicationJob': {
            'replicationJobId': 'string',
            'serverId': 'string',
            'serverType': 'VIRTUAL_MACHINE',
            'vmServer': {
                'vmServerAddress': {
                    'vmManagerId': 'string',
                    'vmId': 'string'
                },
                'vmName': 'string',
                'vmManagerName': 'string',
                'vmManagerType': 'VSPHERE',
                'vmPath': 'string'
            },
            'seedReplicationTime': datetime(2015, 1, 1),
            'frequency': 123,
            'nextReplicationRunStartTime': datetime(2015, 1, 1),
            'licenseType': 'AWS'|'BYOL',
            'roleName': 'string',
            'latestAmiId': 'string',
            'state': 'PENDING'|'ACTIVE'|'FAILED'|'DELETING'|'DELETED',
            'statusMessage': 'string',
            'description': 'string',
            'replicationRunList': [
                {
                    'replicationRunId': 'string',
                    'state': 'PENDING'|'MISSED'|'ACTIVE'|'FAILED'|'COMPLETED'|'DELETING'|'DELETED',
                    'type': 'ON_DEMAND'|'AUTOMATIC',
                    'statusMessage': 'string',
                    'amiId': 'string',
                    'scheduledStartTime': datetime(2015, 1, 1),
                    'completedTime': datetime(2015, 1, 1),
                    'description': 'string'
                },
            ]
        },
        'replicationRunList': [
            {
                'replicationRunId': 'string',
                'state': 'PENDING'|'MISSED'|'ACTIVE'|'FAILED'|'COMPLETED'|'DELETING'|'DELETED',
                'type': 'ON_DEMAND'|'AUTOMATIC',
                'statusMessage': 'string',
                'amiId': 'string',
                'scheduledStartTime': datetime(2015, 1, 1),
                'completedTime': datetime(2015, 1, 1),
                'description': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (dict) --
    replicationJob (dict) -- Object representing a Replication Job
    replicationJobId (string) -- The unique identifier for a Replication Job.
    serverId (string) -- Unique Identifier for a server
    serverType (string) -- Type of server.
    vmServer (dict) -- Object representing a VM server
    vmServerAddress (dict) -- Object representing a server's location
    vmManagerId (string) -- Unique Identifier for VM Manager
    vmId (string) -- Unique Identifier for a VM
    
    
    vmName (string) -- Name of Virtual Machine
    vmManagerName (string) -- VM Manager Name
    vmManagerType (string) -- VM Management Product
    vmPath (string) -- Path to VM
    
    
    seedReplicationTime (datetime) -- Timestamp of an operation
    frequency (integer) -- Interval between Replication Runs. This value is specified in hours, and represents the time between consecutive Replication Runs.
    nextReplicationRunStartTime (datetime) -- Timestamp of an operation
    licenseType (string) -- The license type to be used for the Amazon Machine Image (AMI) created after a successful ReplicationRun.
    roleName (string) -- Name of service role in customer's account to be used by SMS service.
    latestAmiId (string) -- The AMI id for the image resulting from a Replication Run.
    state (string) -- Current state of Replication Job
    statusMessage (string) -- String describing current status of Replication Job
    description (string) -- The description for a Replication Job/Run.
    replicationRunList (list) -- List of Replication Runs
    (dict) -- Object representing a Replication Run
    replicationRunId (string) -- The unique identifier for a Replication Run.
    state (string) -- Current state of Replication Run
    type (string) -- Type of Replication Run
    statusMessage (string) -- String describing current status of Replication Run
    amiId (string) -- The AMI id for the image resulting from a Replication Run.
    scheduledStartTime (datetime) -- Timestamp of an operation
    completedTime (datetime) -- Timestamp of an operation
    description (string) -- The description for a Replication Job/Run.
    
    
    
    
    
    
    replicationRunList (list) -- List of Replication Runs
    (dict) -- Object representing a Replication Run
    replicationRunId (string) -- The unique identifier for a Replication Run.
    state (string) -- Current state of Replication Run
    type (string) -- Type of Replication Run
    statusMessage (string) -- String describing current status of Replication Run
    amiId (string) -- The AMI id for the image resulting from a Replication Run.
    scheduledStartTime (datetime) -- Timestamp of an operation
    completedTime (datetime) -- Timestamp of an operation
    description (string) -- The description for a Replication Job/Run.
    
    
    
    
    nextToken (string) -- Pagination token to pass as input to API call
    
    
    
    """
    pass

def get_servers(nextToken=None, maxResults=None):
    """
    The GetServers API returns a list of all servers in your server catalog. For this call to succeed, you must previously have called ImportServerCatalog.
    See also: AWS API Documentation
    
    
    :example: response = client.get_servers(
        nextToken='string',
        maxResults=123
    )
    
    
    :type nextToken: string
    :param nextToken: Pagination token to pass as input to API call

    :type maxResults: integer
    :param maxResults: The maximum number of results to return in one API call. If left empty, this will default to 50.

    :rtype: dict
    :return: {
        'lastModifiedOn': datetime(2015, 1, 1),
        'serverCatalogStatus': 'NOT_IMPORTED'|'IMPORTING'|'AVAILABLE'|'DELETED'|'EXPIRED',
        'serverList': [
            {
                'serverId': 'string',
                'serverType': 'VIRTUAL_MACHINE',
                'vmServer': {
                    'vmServerAddress': {
                        'vmManagerId': 'string',
                        'vmId': 'string'
                    },
                    'vmName': 'string',
                    'vmManagerName': 'string',
                    'vmManagerType': 'VSPHERE',
                    'vmPath': 'string'
                },
                'replicationJobId': 'string',
                'replicationJobTerminated': True|False
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (dict) --
    lastModifiedOn (datetime) -- Timestamp of an operation
    serverCatalogStatus (string) -- Status of Server catalog
    serverList (list) -- List of servers from catalog
    (dict) -- Object representing a server
    serverId (string) -- Unique Identifier for a server
    serverType (string) -- Type of server.
    vmServer (dict) -- Object representing a VM server
    vmServerAddress (dict) -- Object representing a server's location
    vmManagerId (string) -- Unique Identifier for VM Manager
    vmId (string) -- Unique Identifier for a VM
    
    
    vmName (string) -- Name of Virtual Machine
    vmManagerName (string) -- VM Manager Name
    vmManagerType (string) -- VM Management Product
    vmPath (string) -- Path to VM
    
    
    replicationJobId (string) -- The unique identifier for a Replication Job.
    replicationJobTerminated (boolean) -- An indicator of the Replication Job being deleted or failed.
    
    
    
    
    nextToken (string) -- Pagination token to pass as input to API call
    
    
    
    """
    pass

def get_waiter():
    """
    
    """
    pass

def import_server_catalog():
    """
    The ImportServerCatalog API is used to gather the complete list of on-premises servers on your premises. This API call requires connectors to be installed and monitoring all servers you would like imported. This API call returns immediately, but may take some time to retrieve all of the servers.
    See also: AWS API Documentation
    
    
    :example: response = client.import_server_catalog()
    
    
    :rtype: dict
    :return: {}
    
    
    """
    pass

def start_on_demand_replication_run(replicationJobId=None, description=None):
    """
    The StartOnDemandReplicationRun API is used to start a ReplicationRun on demand (in addition to those that are scheduled based on your frequency). This ReplicationRun will start immediately. StartOnDemandReplicationRun is subject to limits on how many on demand ReplicationRuns you may call per 24-hour period.
    See also: AWS API Documentation
    
    
    :example: response = client.start_on_demand_replication_run(
        replicationJobId='string',
        description='string'
    )
    
    
    :type replicationJobId: string
    :param replicationJobId: [REQUIRED] The unique identifier for a Replication Job.

    :type description: string
    :param description: The description for a Replication Job/Run.

    :rtype: dict
    :return: {
        'replicationRunId': 'string'
    }
    
    
    :returns: 
    (dict) --
    replicationRunId (string) -- The unique identifier for a Replication Run.
    
    
    
    """
    pass

def update_replication_job(replicationJobId=None, frequency=None, nextReplicationRunStartTime=None, licenseType=None, roleName=None, description=None):
    """
    The UpdateReplicationJob API is used to change the settings of your existing ReplicationJob created using CreateReplicationJob. Calling this API will affect the next scheduled ReplicationRun.
    See also: AWS API Documentation
    
    
    :example: response = client.update_replication_job(
        replicationJobId='string',
        frequency=123,
        nextReplicationRunStartTime=datetime(2015, 1, 1),
        licenseType='AWS'|'BYOL',
        roleName='string',
        description='string'
    )
    
    
    :type replicationJobId: string
    :param replicationJobId: [REQUIRED] The unique identifier for a Replication Job.

    :type frequency: integer
    :param frequency: Interval between Replication Runs. This value is specified in hours, and represents the time between consecutive Replication Runs.

    :type nextReplicationRunStartTime: datetime
    :param nextReplicationRunStartTime: Timestamp of an operation

    :type licenseType: string
    :param licenseType: The license type to be used for the Amazon Machine Image (AMI) created after a successful ReplicationRun.

    :type roleName: string
    :param roleName: Name of service role in customer's account to be used by SMS service.

    :type description: string
    :param description: The description for a Replication Job/Run.

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def cancel_job(JobId=None, APIVersion=None):
    """
    This operation cancels a specified job. Only the job owner can cancel it. The operation fails if the job has already started or is complete.
    See also: AWS API Documentation
    
    
    :example: response = client.cancel_job(
        JobId='string',
        APIVersion='string'
    )
    
    
    :type JobId: string
    :param JobId: [REQUIRED] A unique identifier which refers to a particular job.

    :type APIVersion: string
    :param APIVersion: Specifies the version of the client tool.

    :rtype: dict
    :return: {
        'Success': True|False
    }
    
    
    :returns: 
    (dict) -- Output structure for the CancelJob operation.
    Success (boolean) -- Specifies whether (true) or not (false) AWS Import/Export updated your job.
    
    
    
    """
    pass

def create_job(JobType=None, Manifest=None, ManifestAddendum=None, ValidateOnly=None, APIVersion=None):
    """
    This operation initiates the process of scheduling an upload or download of your data. You include in the request a manifest that describes the data transfer specifics. The response to the request includes a job ID, which you can use in other operations, a signature that you use to identify your storage device, and the address where you should ship your storage device.
    See also: AWS API Documentation
    
    
    :example: response = client.create_job(
        JobType='Import'|'Export',
        Manifest='string',
        ManifestAddendum='string',
        ValidateOnly=True|False,
        APIVersion='string'
    )
    
    
    :type JobType: string
    :param JobType: [REQUIRED] Specifies whether the job to initiate is an import or export job.

    :type Manifest: string
    :param Manifest: [REQUIRED] The UTF-8 encoded text of the manifest file.

    :type ManifestAddendum: string
    :param ManifestAddendum: For internal use only.

    :type ValidateOnly: boolean
    :param ValidateOnly: [REQUIRED] Validate the manifest and parameter values in the request but do not actually create a job.

    :type APIVersion: string
    :param APIVersion: Specifies the version of the client tool.

    :rtype: dict
    :return: {
        'JobId': 'string',
        'JobType': 'Import'|'Export',
        'Signature': 'string',
        'SignatureFileContents': 'string',
        'WarningMessage': 'string',
        'ArtifactList': [
            {
                'Description': 'string',
                'URL': 'string'
            },
        ]
    }
    
    
    :returns: 
    (dict) -- Output structure for the CreateJob operation.
    JobId (string) -- A unique identifier which refers to a particular job.
    JobType (string) -- Specifies whether the job to initiate is an import or export job.
    Signature (string) -- An encrypted code used to authenticate the request and response, for example, "DV+TpDfx1/TdSE9ktyK9k/bDTVI=". Only use this value is you want to create the signature file yourself. Generally you should use the SignatureFileContents value.
    SignatureFileContents (string) -- The actual text of the SIGNATURE file to be written to disk.
    WarningMessage (string) -- An optional message notifying you of non-fatal issues with the job, such as use of an incompatible Amazon S3 bucket name.
    ArtifactList (list) -- A collection of artifacts.
    (dict) -- A discrete item that contains the description and URL of an artifact (such as a PDF).
    Description (string) -- The associated description for this object.
    URL (string) -- The URL for a given Artifact.
    
    
    
    
    
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_shipping_label(jobIds=None, name=None, company=None, phoneNumber=None, country=None, stateOrProvince=None, city=None, postalCode=None, street1=None, street2=None, street3=None, APIVersion=None):
    """
    This operation generates a pre-paid UPS shipping label that you will use to ship your device to AWS for processing.
    See also: AWS API Documentation
    
    
    :example: response = client.get_shipping_label(
        jobIds=[
            'string',
        ],
        name='string',
        company='string',
        phoneNumber='string',
        country='string',
        stateOrProvince='string',
        city='string',
        postalCode='string',
        street1='string',
        street2='string',
        street3='string',
        APIVersion='string'
    )
    
    
    :type jobIds: list
    :param jobIds: [REQUIRED]
            (string) --
            

    :type name: string
    :param name: Specifies the name of the person responsible for shipping this package.

    :type company: string
    :param company: Specifies the name of the company that will ship this package.

    :type phoneNumber: string
    :param phoneNumber: Specifies the phone number of the person responsible for shipping this package.

    :type country: string
    :param country: Specifies the name of your country for the return address.

    :type stateOrProvince: string
    :param stateOrProvince: Specifies the name of your state or your province for the return address.

    :type city: string
    :param city: Specifies the name of your city for the return address.

    :type postalCode: string
    :param postalCode: Specifies the postal code for the return address.

    :type street1: string
    :param street1: Specifies the first part of the street address for the return address, for example 1234 Main Street.

    :type street2: string
    :param street2: Specifies the optional second part of the street address for the return address, for example Suite 100.

    :type street3: string
    :param street3: Specifies the optional third part of the street address for the return address, for example c/o Jane Doe.

    :type APIVersion: string
    :param APIVersion: Specifies the version of the client tool.

    :rtype: dict
    :return: {
        'ShippingLabelURL': 'string',
        'Warning': 'string'
    }
    
    
    :returns: 
    (dict) --
    ShippingLabelURL (string) --
    Warning (string) --
    
    
    
    """
    pass

def get_status(JobId=None, APIVersion=None):
    """
    This operation returns information about a job, including where the job is in the processing pipeline, the status of the results, and the signature value associated with the job. You can only return information about jobs you own.
    See also: AWS API Documentation
    
    
    :example: response = client.get_status(
        JobId='string',
        APIVersion='string'
    )
    
    
    :type JobId: string
    :param JobId: [REQUIRED] A unique identifier which refers to a particular job.

    :type APIVersion: string
    :param APIVersion: Specifies the version of the client tool.

    :rtype: dict
    :return: {
        'JobId': 'string',
        'JobType': 'Import'|'Export',
        'LocationCode': 'string',
        'LocationMessage': 'string',
        'ProgressCode': 'string',
        'ProgressMessage': 'string',
        'Carrier': 'string',
        'TrackingNumber': 'string',
        'LogBucket': 'string',
        'LogKey': 'string',
        'ErrorCount': 123,
        'Signature': 'string',
        'SignatureFileContents': 'string',
        'CurrentManifest': 'string',
        'CreationDate': datetime(2015, 1, 1),
        'ArtifactList': [
            {
                'Description': 'string',
                'URL': 'string'
            },
        ]
    }
    
    
    :returns: 
    (dict) -- Output structure for the GetStatus operation.
    JobId (string) -- A unique identifier which refers to a particular job.
    JobType (string) -- Specifies whether the job to initiate is an import or export job.
    LocationCode (string) -- A token representing the location of the storage device, such as "AtAWS".
    LocationMessage (string) -- A more human readable form of the physical location of the storage device.
    ProgressCode (string) -- A token representing the state of the job, such as "Started".
    ProgressMessage (string) -- A more human readable form of the job status.
    Carrier (string) -- Name of the shipping company. This value is included when the LocationCode is "Returned".
    TrackingNumber (string) -- The shipping tracking number assigned by AWS Import/Export to the storage device when it's returned to you. We return this value when the LocationCode is "Returned".
    LogBucket (string) -- Amazon S3 bucket for user logs.
    LogKey (string) -- The key where the user logs were stored.
    ErrorCount (integer) -- Number of errors. We return this value when the ProgressCode is Success or SuccessWithErrors.
    Signature (string) -- An encrypted code used to authenticate the request and response, for example, "DV+TpDfx1/TdSE9ktyK9k/bDTVI=". Only use this value is you want to create the signature file yourself. Generally you should use the SignatureFileContents value.
    SignatureFileContents (string) -- An encrypted code used to authenticate the request and response, for example, "DV+TpDfx1/TdSE9ktyK9k/bDTVI=". Only use this value is you want to create the signature file yourself. Generally you should use the SignatureFileContents value.
    CurrentManifest (string) -- The last manifest submitted, which will be used to process the job.
    CreationDate (datetime) -- Timestamp of the CreateJob request in ISO8601 date format. For example "2010-03-28T20:27:35Z".
    ArtifactList (list) -- A collection of artifacts.
    (dict) -- A discrete item that contains the description and URL of an artifact (such as a PDF).
    Description (string) -- The associated description for this object.
    URL (string) -- The URL for a given Artifact.
    
    
    
    
    
    
    
    """
    pass

def get_waiter():
    """
    
    """
    pass

def list_jobs(MaxJobs=None, Marker=None, APIVersion=None):
    """
    This operation returns the jobs associated with the requester. AWS Import/Export lists the jobs in reverse chronological order based on the date of creation. For example if Job Test1 was created 2009Dec30 and Test2 was created 2010Feb05, the ListJobs operation would return Test2 followed by Test1.
    See also: AWS API Documentation
    
    
    :example: response = client.list_jobs(
        MaxJobs=123,
        Marker='string',
        APIVersion='string'
    )
    
    
    :type MaxJobs: integer
    :param MaxJobs: Sets the maximum number of jobs returned in the response. If there are additional jobs that were not returned because MaxJobs was exceeded, the response contains IsTruncatedtrue/IsTruncated. To return the additional jobs, see Marker.

    :type Marker: string
    :param Marker: Specifies the JOBID to start after when listing the jobs created with your account. AWS Import/Export lists your jobs in reverse chronological order. See MaxJobs.

    :type APIVersion: string
    :param APIVersion: Specifies the version of the client tool.

    :rtype: dict
    :return: {
        'Jobs': [
            {
                'JobId': 'string',
                'CreationDate': datetime(2015, 1, 1),
                'IsCanceled': True|False,
                'JobType': 'Import'|'Export'
            },
        ],
        'IsTruncated': True|False
    }
    
    
    :returns: 
    (dict) -- Output structure for the ListJobs operation.
    Jobs (list) -- A list container for Jobs returned by the ListJobs operation.
    (dict) -- Representation of a job returned by the ListJobs operation.
    JobId (string) -- A unique identifier which refers to a particular job.
    CreationDate (datetime) -- Timestamp of the CreateJob request in ISO8601 date format. For example "2010-03-28T20:27:35Z".
    IsCanceled (boolean) -- Indicates whether the job was canceled.
    JobType (string) -- Specifies whether the job to initiate is an import or export job.
    
    
    
    
    IsTruncated (boolean) -- Indicates whether the list of jobs was truncated. If true, then call ListJobs again using the last JobId element as the marker.
    
    
    
    """
    pass

def update_job(JobId=None, Manifest=None, JobType=None, ValidateOnly=None, APIVersion=None):
    """
    You use this operation to change the parameters specified in the original manifest file by supplying a new manifest file. The manifest file attached to this request replaces the original manifest file. You can only use the operation after a CreateJob request but before the data transfer starts and you can only use it on jobs you own.
    See also: AWS API Documentation
    
    
    :example: response = client.update_job(
        JobId='string',
        Manifest='string',
        JobType='Import'|'Export',
        ValidateOnly=True|False,
        APIVersion='string'
    )
    
    
    :type JobId: string
    :param JobId: [REQUIRED] A unique identifier which refers to a particular job.

    :type Manifest: string
    :param Manifest: [REQUIRED] The UTF-8 encoded text of the manifest file.

    :type JobType: string
    :param JobType: [REQUIRED] Specifies whether the job to initiate is an import or export job.

    :type ValidateOnly: boolean
    :param ValidateOnly: [REQUIRED] Validate the manifest and parameter values in the request but do not actually create a job.

    :type APIVersion: string
    :param APIVersion: Specifies the version of the client tool.

    :rtype: dict
    :return: {
        'Success': True|False,
        'WarningMessage': 'string',
        'ArtifactList': [
            {
                'Description': 'string',
                'URL': 'string'
            },
        ]
    }
    
    
    :returns: 
    (dict) -- Output structure for the UpateJob operation.
    Success (boolean) -- Specifies whether (true) or not (false) AWS Import/Export updated your job.
    WarningMessage (string) -- An optional message notifying you of non-fatal issues with the job, such as use of an incompatible Amazon S3 bucket name.
    ArtifactList (list) -- A collection of artifacts.
    (dict) -- A discrete item that contains the description and URL of an artifact (such as a PDF).
    Description (string) -- The associated description for this object.
    URL (string) -- The URL for a given Artifact.
    
    
    
    
    
    
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def allocate_static_ip(staticIpName=None):
    """
    Allocates a static IP address.
    See also: AWS API Documentation
    
    
    :example: response = client.allocate_static_ip(
        staticIpName='string'
    )
    
    
    :type staticIpName: string
    :param staticIpName: [REQUIRED]
            The name of the static IP address.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def attach_static_ip(staticIpName=None, instanceName=None):
    """
    Attaches a static IP address to a specific Amazon Lightsail instance.
    See also: AWS API Documentation
    
    
    :example: response = client.attach_static_ip(
        staticIpName='string',
        instanceName='string'
    )
    
    
    :type staticIpName: string
    :param staticIpName: [REQUIRED]
            The name of the static IP.
            

    :type instanceName: string
    :param instanceName: [REQUIRED]
            The instance name to which you want to attach the static IP address.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def close_instance_public_ports(portInfo=None, instanceName=None):
    """
    Closes the public ports on a specific Amazon Lightsail instance.
    See also: AWS API Documentation
    
    
    :example: response = client.close_instance_public_ports(
        portInfo={
            'fromPort': 123,
            'toPort': 123,
            'protocol': 'tcp'|'all'|'udp'
        },
        instanceName='string'
    )
    
    
    :type portInfo: dict
    :param portInfo: [REQUIRED]
            Information about the public port you are trying to close.
            fromPort (integer) --The first port in the range.
            toPort (integer) --The last port in the range.
            protocol (string) --The protocol.
            

    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance on which you're attempting to close the public ports.
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def create_domain(domainName=None):
    """
    Creates a domain resource for the specified domain (e.g., example.com).
    See also: AWS API Documentation
    
    
    :example: response = client.create_domain(
        domainName='string'
    )
    
    
    :type domainName: string
    :param domainName: [REQUIRED]
            The domain name to manage (e.g., example.com ).
            Note
            You cannot register a new domain name using Lightsail. You must register a domain name using Amazon Route 53 or another domain name registrar. If you have already registered your domain, you can enter its name in this parameter to manage the DNS records for that domain.
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def create_domain_entry(domainName=None, domainEntry=None):
    """
    Creates one of the following entry records associated with the domain: A record, CNAME record, TXT record, or MX record.
    See also: AWS API Documentation
    
    
    :example: response = client.create_domain_entry(
        domainName='string',
        domainEntry={
            'id': 'string',
            'name': 'string',
            'target': 'string',
            'type': 'string',
            'options': {
                'string': 'string'
            }
        }
    )
    
    
    :type domainName: string
    :param domainName: [REQUIRED]
            The domain name (e.g., example.com ) for which you want to create the domain entry.
            

    :type domainEntry: dict
    :param domainEntry: [REQUIRED]
            An array of key-value pairs containing information about the domain entry request.
            id (string) --The ID of the domain recordset entry.
            name (string) --The name of the domain.
            target (string) --The target AWS name server (e.g., ns-111.awsdns-22.com. ).
            type (string) --The type of domain entry (e.g., SOA or NS ).
            options (dict) --The options for the domain entry.
            (string) --
            (string) --
            
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def create_instance_snapshot(instanceSnapshotName=None, instanceName=None):
    """
    Creates a snapshot of a specific virtual private server, or instance . You can use a snapshot to create a new instance that is based on that snapshot.
    See also: AWS API Documentation
    
    
    :example: response = client.create_instance_snapshot(
        instanceSnapshotName='string',
        instanceName='string'
    )
    
    
    :type instanceSnapshotName: string
    :param instanceSnapshotName: [REQUIRED]
            The name for your new snapshot.
            

    :type instanceName: string
    :param instanceName: [REQUIRED]
            The Lightsail instance on which to base your snapshot.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def create_instances(instanceNames=None, availabilityZone=None, customImageName=None, blueprintId=None, bundleId=None, userData=None, keyPairName=None):
    """
    Creates one or more Amazon Lightsail virtual private servers, or instances .
    See also: AWS API Documentation
    
    
    :example: response = client.create_instances(
        instanceNames=[
            'string',
        ],
        availabilityZone='string',
        customImageName='string',
        blueprintId='string',
        bundleId='string',
        userData='string',
        keyPairName='string'
    )
    
    
    :type instanceNames: list
    :param instanceNames: [REQUIRED]
            The names to use for your new Lightsail instances. Separate multiple values using quotation marks and commas, for example: ['MyFirstInstance','MySecondInstance']
            (string) --
            

    :type availabilityZone: string
    :param availabilityZone: [REQUIRED]
            The Availability Zone in which to create your instance. Use the following format: us-east-1a (case sensitive). You can get a list of availability zones by using the get regions operation. Be sure to add the include availability zones parameter to your request.
            

    :type customImageName: string
    :param customImageName: The name for your custom image.

    :type blueprintId: string
    :param blueprintId: [REQUIRED]
            The ID for a virtual private server image (e.g., app_wordpress_4_4 or app_lamp_7_0 ). Use the get blueprints operation to return a list of available images (or blueprints ).
            

    :type bundleId: string
    :param bundleId: [REQUIRED]
            The bundle of specification information for your virtual private server (or instance ), including the pricing plan (e.g., micro_1_0 ).
            

    :type userData: string
    :param userData: A launch script you can create that configures a server with additional user data. For example, you might want to run apt-get  y update .
            Note
            Depending on the machine image you choose, the command to get software on your instance varies. Amazon Linux and CentOS use yum , Debian and Ubuntu use apt-get , and FreeBSD uses pkg . For a complete list, see the Dev Guide .
            

    :type keyPairName: string
    :param keyPairName: The name of your key pair.

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def create_instances_from_snapshot(instanceNames=None, availabilityZone=None, instanceSnapshotName=None, bundleId=None, userData=None, keyPairName=None):
    """
    Uses a specific snapshot as a blueprint for creating one or more new instances that are based on that identical configuration.
    See also: AWS API Documentation
    
    
    :example: response = client.create_instances_from_snapshot(
        instanceNames=[
            'string',
        ],
        availabilityZone='string',
        instanceSnapshotName='string',
        bundleId='string',
        userData='string',
        keyPairName='string'
    )
    
    
    :type instanceNames: list
    :param instanceNames: [REQUIRED]
            The names for your new instances.
            (string) --
            

    :type availabilityZone: string
    :param availabilityZone: [REQUIRED]
            The Availability Zone where you want to create your instances. Use the following formatting: us-east-1a (case sensitive). You can get a list of availability zones by using the get regions operation. Be sure to add the include availability zones parameter to your request.
            

    :type instanceSnapshotName: string
    :param instanceSnapshotName: [REQUIRED]
            The name of the instance snapshot on which you are basing your new instances. Use the get instance snapshots operation to return information about your existing snapshots.
            

    :type bundleId: string
    :param bundleId: [REQUIRED]
            The bundle of specification information for your virtual private server (or instance ), including the pricing plan (e.g., micro_1_0 ).
            

    :type userData: string
    :param userData: You can create a launch script that configures a server with additional user data. For example, apt-get  y update .
            Note
            Depending on the machine image you choose, the command to get software on your instance varies. Amazon Linux and CentOS use yum , Debian and Ubuntu use apt-get , and FreeBSD uses pkg . For a complete list, see the Dev Guide .
            

    :type keyPairName: string
    :param keyPairName: The name for your key pair.

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def create_key_pair(keyPairName=None):
    """
    Creates sn SSH key pair.
    See also: AWS API Documentation
    
    
    :example: response = client.create_key_pair(
        keyPairName='string'
    )
    
    
    :type keyPairName: string
    :param keyPairName: [REQUIRED]
            The name for your new key pair.
            

    :rtype: dict
    :return: {
        'keyPair': {
            'name': 'string',
            'arn': 'string',
            'supportCode': 'string',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'fingerprint': 'string'
        },
        'publicKeyBase64': 'string',
        'privateKeyBase64': 'string',
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def delete_domain(domainName=None):
    """
    Deletes the specified domain recordset and all of its domain records.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_domain(
        domainName='string'
    )
    
    
    :type domainName: string
    :param domainName: [REQUIRED]
            The specific domain name to delete.
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def delete_domain_entry(domainName=None, domainEntry=None):
    """
    Deletes a specific domain entry.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_domain_entry(
        domainName='string',
        domainEntry={
            'id': 'string',
            'name': 'string',
            'target': 'string',
            'type': 'string',
            'options': {
                'string': 'string'
            }
        }
    )
    
    
    :type domainName: string
    :param domainName: [REQUIRED]
            The name of the domain entry to delete.
            

    :type domainEntry: dict
    :param domainEntry: [REQUIRED]
            An array of key-value pairs containing information about your domain entries.
            id (string) --The ID of the domain recordset entry.
            name (string) --The name of the domain.
            target (string) --The target AWS name server (e.g., ns-111.awsdns-22.com. ).
            type (string) --The type of domain entry (e.g., SOA or NS ).
            options (dict) --The options for the domain entry.
            (string) --
            (string) --
            
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def delete_instance(instanceName=None):
    """
    Deletes a specific Amazon Lightsail virtual private server, or instance .
    See also: AWS API Documentation
    
    
    :example: response = client.delete_instance(
        instanceName='string'
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance to delete.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def delete_instance_snapshot(instanceSnapshotName=None):
    """
    Deletes a specific snapshot of a virtual private server (or instance ).
    See also: AWS API Documentation
    
    
    :example: response = client.delete_instance_snapshot(
        instanceSnapshotName='string'
    )
    
    
    :type instanceSnapshotName: string
    :param instanceSnapshotName: [REQUIRED]
            The name of the snapshot to delete.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def delete_key_pair(keyPairName=None):
    """
    Deletes a specific SSH key pair.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_key_pair(
        keyPairName='string'
    )
    
    
    :type keyPairName: string
    :param keyPairName: [REQUIRED]
            The name of the key pair to delete.
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def detach_static_ip(staticIpName=None):
    """
    Detaches a static IP from the Amazon Lightsail instance to which it is attached.
    See also: AWS API Documentation
    
    
    :example: response = client.detach_static_ip(
        staticIpName='string'
    )
    
    
    :type staticIpName: string
    :param staticIpName: [REQUIRED]
            The name of the static IP to detach from the instance.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def download_default_key_pair():
    """
    Downloads the default SSH key pair from the user's account.
    See also: AWS API Documentation
    
    
    :example: response = client.download_default_key_pair()
    
    
    :rtype: dict
    :return: {
        'publicKeyBase64': 'string',
        'privateKeyBase64': 'string'
    }
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_active_names(pageToken=None):
    """
    Returns the names of all active (not deleted) resources.
    See also: AWS API Documentation
    
    
    :example: response = client.get_active_names(
        pageToken='string'
    )
    
    
    :type pageToken: string
    :param pageToken: A token used for paginating results from your get active names request.

    :rtype: dict
    :return: {
        'activeNames': [
            'string',
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_blueprints(includeInactive=None, pageToken=None):
    """
    Returns the list of available instance images, or blueprints . You can use a blueprint to create a new virtual private server already running a specific operating system, as well as a preinstalled app or development stack. The software each instance is running depends on the blueprint image you choose.
    See also: AWS API Documentation
    
    
    :example: response = client.get_blueprints(
        includeInactive=True|False,
        pageToken='string'
    )
    
    
    :type includeInactive: boolean
    :param includeInactive: A Boolean value indicating whether to include inactive results in your request.

    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get blueprints request.

    :rtype: dict
    :return: {
        'blueprints': [
            {
                'blueprintId': 'string',
                'name': 'string',
                'group': 'string',
                'type': 'os'|'app',
                'description': 'string',
                'isActive': True|False,
                'minPower': 123,
                'version': 'string',
                'versionCode': 'string',
                'productUrl': 'string',
                'licenseUrl': 'string'
            },
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_bundles(includeInactive=None, pageToken=None):
    """
    Returns the list of bundles that are available for purchase. A bundle describes the specs for your virtual private server (or instance ).
    See also: AWS API Documentation
    
    
    :example: response = client.get_bundles(
        includeInactive=True|False,
        pageToken='string'
    )
    
    
    :type includeInactive: boolean
    :param includeInactive: A Boolean value that indicates whether to include inactive bundle results in your request.

    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get bundles request.

    :rtype: dict
    :return: {
        'bundles': [
            {
                'price': ...,
                'cpuCount': 123,
                'diskSizeInGb': 123,
                'bundleId': 'string',
                'instanceType': 'string',
                'isActive': True|False,
                'name': 'string',
                'power': 123,
                'ramSizeInGb': ...,
                'transferPerMonthInGb': 123
            },
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_domain(domainName=None):
    """
    Returns information about a specific domain recordset.
    See also: AWS API Documentation
    
    
    :example: response = client.get_domain(
        domainName='string'
    )
    
    
    :type domainName: string
    :param domainName: [REQUIRED]
            The domain name for which your want to return information about.
            

    :rtype: dict
    :return: {
        'domain': {
            'name': 'string',
            'arn': 'string',
            'supportCode': 'string',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'domainEntries': [
                {
                    'id': 'string',
                    'name': 'string',
                    'target': 'string',
                    'type': 'string',
                    'options': {
                        'string': 'string'
                    }
                },
            ]
        }
    }
    
    
    """
    pass

def get_domains(pageToken=None):
    """
    Returns a list of all domains in the user's account.
    See also: AWS API Documentation
    
    
    :example: response = client.get_domains(
        pageToken='string'
    )
    
    
    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get domains request.

    :rtype: dict
    :return: {
        'domains': [
            {
                'name': 'string',
                'arn': 'string',
                'supportCode': 'string',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'domainEntries': [
                    {
                        'id': 'string',
                        'name': 'string',
                        'target': 'string',
                        'type': 'string',
                        'options': {
                            'string': 'string'
                        }
                    },
                ]
            },
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_instance(instanceName=None):
    """
    Returns information about a specific Amazon Lightsail instance, which is a virtual private server.
    See also: AWS API Documentation
    
    
    :example: response = client.get_instance(
        instanceName='string'
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance.
            

    :rtype: dict
    :return: {
        'instance': {
            'name': 'string',
            'arn': 'string',
            'supportCode': 'string',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'blueprintId': 'string',
            'blueprintName': 'string',
            'bundleId': 'string',
            'isStaticIp': True|False,
            'privateIpAddress': 'string',
            'publicIpAddress': 'string',
            'ipv6Address': 'string',
            'hardware': {
                'cpuCount': 123,
                'disks': [
                    {
                        'name': 'string',
                        'arn': 'string',
                        'supportCode': 'string',
                        'createdAt': datetime(2015, 1, 1),
                        'location': {
                            'availabilityZone': 'string',
                            'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                        },
                        'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                        'sizeInGb': 123,
                        'gbInUse': 123,
                        'isSystemDisk': True|False,
                        'iops': 123,
                        'path': 'string',
                        'attachedTo': 'string',
                        'isAttached': True|False,
                        'attachmentState': 'string'
                    },
                ],
                'ramSizeInGb': ...
            },
            'networking': {
                'monthlyTransfer': {
                    'gbPerMonthAllocated': 123
                },
                'ports': [
                    {
                        'fromPort': 123,
                        'toPort': 123,
                        'protocol': 'tcp'|'all'|'udp',
                        'accessFrom': 'string',
                        'accessType': 'Public'|'Private',
                        'commonName': 'string',
                        'accessDirection': 'inbound'|'outbound'
                    },
                ]
            },
            'state': {
                'code': 123,
                'name': 'string'
            },
            'username': 'string',
            'sshKeyName': 'string'
        }
    }
    
    
    """
    pass

def get_instance_access_details(instanceName=None, protocol=None):
    """
    Returns temporary SSH keys you can use to connect to a specific virtual private server, or instance .
    See also: AWS API Documentation
    
    
    :example: response = client.get_instance_access_details(
        instanceName='string',
        protocol='ssh'|'rdp'
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance to access.
            

    :type protocol: string
    :param protocol: The protocol to use to connect to your instance. Defaults to ssh .

    :rtype: dict
    :return: {
        'accessDetails': {
            'certKey': 'string',
            'expiresAt': datetime(2015, 1, 1),
            'ipAddress': 'string',
            'password': 'string',
            'privateKey': 'string',
            'protocol': 'ssh'|'rdp',
            'instanceName': 'string',
            'username': 'string'
        }
    }
    
    
    """
    pass

def get_instance_metric_data(instanceName=None, metricName=None, period=None, startTime=None, endTime=None, unit=None, statistics=None):
    """
    Returns the data points for the specified Amazon Lightsail instance metric, given an instance name.
    See also: AWS API Documentation
    
    
    :example: response = client.get_instance_metric_data(
        instanceName='string',
        metricName='CPUUtilization'|'NetworkIn'|'NetworkOut'|'StatusCheckFailed'|'StatusCheckFailed_Instance'|'StatusCheckFailed_System',
        period=123,
        startTime=datetime(2015, 1, 1),
        endTime=datetime(2015, 1, 1),
        unit='Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None',
        statistics=[
            'Minimum'|'Maximum'|'Sum'|'Average'|'SampleCount',
        ]
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance for which you want to get metrics data.
            

    :type metricName: string
    :param metricName: [REQUIRED]
            The metric name to get data about.
            

    :type period: integer
    :param period: [REQUIRED]
            The time period for which you are requesting data.
            

    :type startTime: datetime
    :param startTime: [REQUIRED]
            The start time of the time period.
            

    :type endTime: datetime
    :param endTime: [REQUIRED]
            The end time of the time period.
            

    :type unit: string
    :param unit: [REQUIRED]
            The unit. The list of valid values is below.
            

    :type statistics: list
    :param statistics: [REQUIRED]
            The instance statistics.
            (string) --
            

    :rtype: dict
    :return: {
        'metricName': 'CPUUtilization'|'NetworkIn'|'NetworkOut'|'StatusCheckFailed'|'StatusCheckFailed_Instance'|'StatusCheckFailed_System',
        'metricData': [
            {
                'average': 123.0,
                'maximum': 123.0,
                'minimum': 123.0,
                'sampleCount': 123.0,
                'sum': 123.0,
                'timestamp': datetime(2015, 1, 1),
                'unit': 'Seconds'|'Microseconds'|'Milliseconds'|'Bytes'|'Kilobytes'|'Megabytes'|'Gigabytes'|'Terabytes'|'Bits'|'Kilobits'|'Megabits'|'Gigabits'|'Terabits'|'Percent'|'Count'|'Bytes/Second'|'Kilobytes/Second'|'Megabytes/Second'|'Gigabytes/Second'|'Terabytes/Second'|'Bits/Second'|'Kilobits/Second'|'Megabits/Second'|'Gigabits/Second'|'Terabits/Second'|'Count/Second'|'None'
            },
        ]
    }
    
    
    """
    pass

def get_instance_port_states(instanceName=None):
    """
    Returns the port states for a specific virtual private server, or instance .
    See also: AWS API Documentation
    
    
    :example: response = client.get_instance_port_states(
        instanceName='string'
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance.
            

    :rtype: dict
    :return: {
        'portStates': [
            {
                'fromPort': 123,
                'toPort': 123,
                'protocol': 'tcp'|'all'|'udp',
                'state': 'open'|'closed'
            },
        ]
    }
    
    
    """
    pass

def get_instance_snapshot(instanceSnapshotName=None):
    """
    Returns information about a specific instance snapshot.
    See also: AWS API Documentation
    
    
    :example: response = client.get_instance_snapshot(
        instanceSnapshotName='string'
    )
    
    
    :type instanceSnapshotName: string
    :param instanceSnapshotName: [REQUIRED]
            The name of the snapshot for which you are requesting information.
            

    :rtype: dict
    :return: {
        'instanceSnapshot': {
            'name': 'string',
            'arn': 'string',
            'supportCode': 'string',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'state': 'pending'|'error'|'available',
            'progress': 'string',
            'fromInstanceName': 'string',
            'fromInstanceArn': 'string',
            'fromBlueprintId': 'string',
            'fromBundleId': 'string',
            'sizeInGb': 123
        }
    }
    
    
    """
    pass

def get_instance_snapshots(pageToken=None):
    """
    Returns all instance snapshots for the user's account.
    See also: AWS API Documentation
    
    
    :example: response = client.get_instance_snapshots(
        pageToken='string'
    )
    
    
    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get instance snapshots request.

    :rtype: dict
    :return: {
        'instanceSnapshots': [
            {
                'name': 'string',
                'arn': 'string',
                'supportCode': 'string',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'state': 'pending'|'error'|'available',
                'progress': 'string',
                'fromInstanceName': 'string',
                'fromInstanceArn': 'string',
                'fromBlueprintId': 'string',
                'fromBundleId': 'string',
                'sizeInGb': 123
            },
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_instance_state(instanceName=None):
    """
    Returns the state of a specific instance. Works on one instance at a time.
    See also: AWS API Documentation
    
    
    :example: response = client.get_instance_state(
        instanceName='string'
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance to get state information about.
            

    :rtype: dict
    :return: {
        'state': {
            'code': 123,
            'name': 'string'
        }
    }
    
    
    """
    pass

def get_instances(pageToken=None):
    """
    Returns information about all Amazon Lightsail virtual private servers, or instances .
    See also: AWS API Documentation
    
    
    :example: response = client.get_instances(
        pageToken='string'
    )
    
    
    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get instances request.

    :rtype: dict
    :return: {
        'instances': [
            {
                'name': 'string',
                'arn': 'string',
                'supportCode': 'string',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'blueprintId': 'string',
                'blueprintName': 'string',
                'bundleId': 'string',
                'isStaticIp': True|False,
                'privateIpAddress': 'string',
                'publicIpAddress': 'string',
                'ipv6Address': 'string',
                'hardware': {
                    'cpuCount': 123,
                    'disks': [
                        {
                            'name': 'string',
                            'arn': 'string',
                            'supportCode': 'string',
                            'createdAt': datetime(2015, 1, 1),
                            'location': {
                                'availabilityZone': 'string',
                                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                            },
                            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                            'sizeInGb': 123,
                            'gbInUse': 123,
                            'isSystemDisk': True|False,
                            'iops': 123,
                            'path': 'string',
                            'attachedTo': 'string',
                            'isAttached': True|False,
                            'attachmentState': 'string'
                        },
                    ],
                    'ramSizeInGb': ...
                },
                'networking': {
                    'monthlyTransfer': {
                        'gbPerMonthAllocated': 123
                    },
                    'ports': [
                        {
                            'fromPort': 123,
                            'toPort': 123,
                            'protocol': 'tcp'|'all'|'udp',
                            'accessFrom': 'string',
                            'accessType': 'Public'|'Private',
                            'commonName': 'string',
                            'accessDirection': 'inbound'|'outbound'
                        },
                    ]
                },
                'state': {
                    'code': 123,
                    'name': 'string'
                },
                'username': 'string',
                'sshKeyName': 'string'
            },
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_key_pair(keyPairName=None):
    """
    Returns information about a specific key pair.
    See also: AWS API Documentation
    
    
    :example: response = client.get_key_pair(
        keyPairName='string'
    )
    
    
    :type keyPairName: string
    :param keyPairName: [REQUIRED]
            The name of the key pair for which you are requesting information.
            

    :rtype: dict
    :return: {
        'keyPair': {
            'name': 'string',
            'arn': 'string',
            'supportCode': 'string',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'fingerprint': 'string'
        }
    }
    
    
    """
    pass

def get_key_pairs(pageToken=None):
    """
    Returns information about all key pairs in the user's account.
    See also: AWS API Documentation
    
    
    :example: response = client.get_key_pairs(
        pageToken='string'
    )
    
    
    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get key pairs request.

    :rtype: dict
    :return: {
        'keyPairs': [
            {
                'name': 'string',
                'arn': 'string',
                'supportCode': 'string',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'fingerprint': 'string'
            },
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_operation(operationId=None):
    """
    Returns information about a specific operation. Operations include events such as when you create an instance, allocate a static IP, attach a static IP, and so on.
    See also: AWS API Documentation
    
    
    :example: response = client.get_operation(
        operationId='string'
    )
    
    
    :type operationId: string
    :param operationId: [REQUIRED]
            A GUID used to identify the operation.
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def get_operations(pageToken=None):
    """
    Returns information about all operations.
    Results are returned from oldest to newest, up to a maximum of 200. Results can be paged by making each subsequent call to GetOperations use the maximum (last) statusChangedAt value from the previous request.
    See also: AWS API Documentation
    
    
    :example: response = client.get_operations(
        pageToken='string'
    )
    
    
    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get operations request.

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_operations_for_resource(resourceName=None, pageToken=None):
    """
    Gets operations for a specific resource (e.g., an instance or a static IP).
    See also: AWS API Documentation
    
    
    :example: response = client.get_operations_for_resource(
        resourceName='string',
        pageToken='string'
    )
    
    
    :type resourceName: string
    :param resourceName: [REQUIRED]
            The name of the resource for which you are requesting information.
            

    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get operations for resource request.

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ],
        'nextPageCount': 'string'
    }
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_regions(includeAvailabilityZones=None):
    """
    Returns a list of all valid regions for Amazon Lightsail. Use the include availability zones parameter to also return the availability zones in a region.
    See also: AWS API Documentation
    
    
    :example: response = client.get_regions(
        includeAvailabilityZones=True|False
    )
    
    
    :type includeAvailabilityZones: boolean
    :param includeAvailabilityZones: A Boolean value indicating whether to also include Availability Zones in your get regions request. Availability Zones are indicated with a letter: e.g., us-east-1a .

    :rtype: dict
    :return: {
        'regions': [
            {
                'continentCode': 'string',
                'description': 'string',
                'displayName': 'string',
                'name': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2',
                'availabilityZones': [
                    {
                        'zoneName': 'string',
                        'state': 'string'
                    },
                ]
            },
        ]
    }
    
    
    """
    pass

def get_static_ip(staticIpName=None):
    """
    Returns information about a specific static IP.
    See also: AWS API Documentation
    
    
    :example: response = client.get_static_ip(
        staticIpName='string'
    )
    
    
    :type staticIpName: string
    :param staticIpName: [REQUIRED]
            The name of the static IP in Lightsail.
            

    :rtype: dict
    :return: {
        'staticIp': {
            'name': 'string',
            'arn': 'string',
            'supportCode': 'string',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'ipAddress': 'string',
            'attachedTo': 'string',
            'isAttached': True|False
        }
    }
    
    
    """
    pass

def get_static_ips(pageToken=None):
    """
    Returns information about all static IPs in the user's account.
    See also: AWS API Documentation
    
    
    :example: response = client.get_static_ips(
        pageToken='string'
    )
    
    
    :type pageToken: string
    :param pageToken: A token used for advancing to the next page of results from your get static IPs request.

    :rtype: dict
    :return: {
        'staticIps': [
            {
                'name': 'string',
                'arn': 'string',
                'supportCode': 'string',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'ipAddress': 'string',
                'attachedTo': 'string',
                'isAttached': True|False
            },
        ],
        'nextPageToken': 'string'
    }
    
    
    """
    pass

def get_waiter():
    """
    
    """
    pass

def import_key_pair(keyPairName=None, publicKeyBase64=None):
    """
    Imports a public SSH key from a specific key pair.
    See also: AWS API Documentation
    
    
    :example: response = client.import_key_pair(
        keyPairName='string',
        publicKeyBase64='string'
    )
    
    
    :type keyPairName: string
    :param keyPairName: [REQUIRED]
            The name of the key pair for which you want to import the public key.
            

    :type publicKeyBase64: string
    :param publicKeyBase64: [REQUIRED]
            A base64-encoded public key of the ssh-rsa type.
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def is_vpc_peered():
    """
    Returns a Boolean value indicating whether your Lightsail VPC is peered.
    See also: AWS API Documentation
    
    
    :example: response = client.is_vpc_peered()
    
    
    :rtype: dict
    :return: {
        'isPeered': True|False
    }
    
    
    """
    pass

def open_instance_public_ports(portInfo=None, instanceName=None):
    """
    Adds public ports to an Amazon Lightsail instance.
    See also: AWS API Documentation
    
    
    :example: response = client.open_instance_public_ports(
        portInfo={
            'fromPort': 123,
            'toPort': 123,
            'protocol': 'tcp'|'all'|'udp'
        },
        instanceName='string'
    )
    
    
    :type portInfo: dict
    :param portInfo: [REQUIRED]
            An array of key-value pairs containing information about the port mappings.
            fromPort (integer) --The first port in the range.
            toPort (integer) --The last port in the range.
            protocol (string) --The protocol.
            

    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance for which you want to open the public ports.
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def peer_vpc():
    """
    Tries to peer the Lightsail VPC with the user's default VPC.
    See also: AWS API Documentation
    
    
    :example: response = client.peer_vpc()
    
    
    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def put_instance_public_ports(portInfos=None, instanceName=None):
    """
    Sets the specified open ports for an Amazon Lightsail instance, and closes all ports for every protocol not included in the current request.
    See also: AWS API Documentation
    
    
    :example: response = client.put_instance_public_ports(
        portInfos=[
            {
                'fromPort': 123,
                'toPort': 123,
                'protocol': 'tcp'|'all'|'udp'
            },
        ],
        instanceName='string'
    )
    
    
    :type portInfos: list
    :param portInfos: [REQUIRED]
            Specifies information about the public port(s).
            (dict) --Describes information about the ports on your virtual private server (or instance ).
            fromPort (integer) --The first port in the range.
            toPort (integer) --The last port in the range.
            protocol (string) --The protocol.
            
            

    :type instanceName: string
    :param instanceName: [REQUIRED]
            The Lightsail instance name of the public port(s) you are setting.
            

    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def reboot_instance(instanceName=None):
    """
    Restarts a specific instance. When your Amazon Lightsail instance is finished rebooting, Lightsail assigns a new public IP address. To use the same IP address after restarting, create a static IP address and attach it to the instance.
    See also: AWS API Documentation
    
    
    :example: response = client.reboot_instance(
        instanceName='string'
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance to reboot.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def release_static_ip(staticIpName=None):
    """
    Deletes a specific static IP from your account.
    See also: AWS API Documentation
    
    
    :example: response = client.release_static_ip(
        staticIpName='string'
    )
    
    
    :type staticIpName: string
    :param staticIpName: [REQUIRED]
            The name of the static IP to delete.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def start_instance(instanceName=None):
    """
    Starts a specific Amazon Lightsail instance from a stopped state. To restart an instance, use the reboot instance operation.
    See also: AWS API Documentation
    
    
    :example: response = client.start_instance(
        instanceName='string'
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance (a virtual private server) to start.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def stop_instance(instanceName=None):
    """
    Stops a specific Amazon Lightsail instance that is currently running.
    See also: AWS API Documentation
    
    
    :example: response = client.stop_instance(
        instanceName='string'
    )
    
    
    :type instanceName: string
    :param instanceName: [REQUIRED]
            The name of the instance (a virtual private server) to stop.
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass

def unpeer_vpc():
    """
    Attempts to unpeer the Lightsail VPC from the user's default VPC.
    See also: AWS API Documentation
    
    
    :example: response = client.unpeer_vpc()
    
    
    :rtype: dict
    :return: {
        'operation': {
            'id': 'string',
            'resourceName': 'string',
            'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
            'createdAt': datetime(2015, 1, 1),
            'location': {
                'availabilityZone': 'string',
                'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
            },
            'isTerminal': True|False,
            'operationDetails': 'string',
            'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
            'status': 'NotStarted'|'Started'|'Failed'|'Completed',
            'statusChangedAt': datetime(2015, 1, 1),
            'errorCode': 'string',
            'errorDetails': 'string'
        }
    }
    
    
    """
    pass

def update_domain_entry(domainName=None, domainEntry=None):
    """
    Updates a domain recordset after it is created.
    See also: AWS API Documentation
    
    
    :example: response = client.update_domain_entry(
        domainName='string',
        domainEntry={
            'id': 'string',
            'name': 'string',
            'target': 'string',
            'type': 'string',
            'options': {
                'string': 'string'
            }
        }
    )
    
    
    :type domainName: string
    :param domainName: [REQUIRED]
            The name of the domain recordset to update.
            

    :type domainEntry: dict
    :param domainEntry: [REQUIRED]
            An array of key-value pairs containing information about the domain entry.
            id (string) --The ID of the domain recordset entry.
            name (string) --The name of the domain.
            target (string) --The target AWS name server (e.g., ns-111.awsdns-22.com. ).
            type (string) --The type of domain entry (e.g., SOA or NS ).
            options (dict) --The options for the domain entry.
            (string) --
            (string) --
            
            

    :rtype: dict
    :return: {
        'operations': [
            {
                'id': 'string',
                'resourceName': 'string',
                'resourceType': 'Instance'|'StaticIp'|'KeyPair'|'InstanceSnapshot'|'Domain'|'PeeredVpc',
                'createdAt': datetime(2015, 1, 1),
                'location': {
                    'availabilityZone': 'string',
                    'regionName': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-west-1'|'eu-central-1'|'ap-south-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1'|'ap-northeast-2'
                },
                'isTerminal': True|False,
                'operationDetails': 'string',
                'operationType': 'DeleteInstance'|'CreateInstance'|'StopInstance'|'StartInstance'|'RebootInstance'|'OpenInstancePublicPorts'|'PutInstancePublicPorts'|'CloseInstancePublicPorts'|'AllocateStaticIp'|'ReleaseStaticIp'|'AttachStaticIp'|'DetachStaticIp'|'UpdateDomainEntry'|'DeleteDomainEntry'|'CreateDomain'|'DeleteDomain'|'CreateInstanceSnapshot'|'DeleteInstanceSnapshot'|'CreateInstancesFromSnapshot',
                'status': 'NotStarted'|'Started'|'Failed'|'Completed',
                'statusChangedAt': datetime(2015, 1, 1),
                'errorCode': 'string',
                'errorDetails': 'string'
            },
        ]
    }
    
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def associate_configuration_items_to_application(applicationConfigurationId=None, configurationIds=None):
    """
    Associates one or more configuration items with an application.
    See also: AWS API Documentation
    
    
    :example: response = client.associate_configuration_items_to_application(
        applicationConfigurationId='string',
        configurationIds=[
            'string',
        ]
    )
    
    
    :type applicationConfigurationId: string
    :param applicationConfigurationId: [REQUIRED]
            The configuration ID of an application with which items are to be associated.
            

    :type configurationIds: list
    :param configurationIds: [REQUIRED]
            The ID of each configuration item to be associated with an application.
            (string) --
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def create_application(name=None, description=None):
    """
    Creates an application with the given name and description.
    See also: AWS API Documentation
    
    
    :example: response = client.create_application(
        name='string',
        description='string'
    )
    
    
    :type name: string
    :param name: [REQUIRED]
            Name of the application to be created.
            

    :type description: string
    :param description: Description of the application to be created.

    :rtype: dict
    :return: {
        'configurationId': 'string'
    }
    
    
    """
    pass

def create_tags(configurationIds=None, tags=None):
    """
    Creates one or more tags for configuration items. Tags are metadata that help you categorize IT assets. This API accepts a list of multiple configuration items.
    See also: AWS API Documentation
    
    
    :example: response = client.create_tags(
        configurationIds=[
            'string',
        ],
        tags=[
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    )
    
    
    :type configurationIds: list
    :param configurationIds: [REQUIRED]
            A list of configuration items that you want to tag.
            (string) --
            

    :type tags: list
    :param tags: [REQUIRED]
            Tags that you want to associate with one or more configuration items. Specify the tags that you want to create in a key -value format. For example:
            {'key': 'serverType', 'value': 'webServer'}
            (dict) --Metadata that help you categorize IT assets.
            key (string) -- [REQUIRED]The type of tag on which to filter.
            value (string) -- [REQUIRED]A value for a tag key on which to filter.
            
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def delete_applications(configurationIds=None):
    """
    Deletes a list of applications and their associations with configuration items.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_applications(
        configurationIds=[
            'string',
        ]
    )
    
    
    :type configurationIds: list
    :param configurationIds: [REQUIRED]
            Configuration ID of an application to be deleted.
            (string) --
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def delete_tags(configurationIds=None, tags=None):
    """
    Deletes the association between configuration items and one or more tags. This API accepts a list of multiple configuration items.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_tags(
        configurationIds=[
            'string',
        ],
        tags=[
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    )
    
    
    :type configurationIds: list
    :param configurationIds: [REQUIRED]
            A list of configuration items with tags that you want to delete.
            (string) --
            

    :type tags: list
    :param tags: Tags that you want to delete from one or more configuration items. Specify the tags that you want to delete in a key -value format. For example:
            {'key': 'serverType', 'value': 'webServer'}
            (dict) --Metadata that help you categorize IT assets.
            key (string) -- [REQUIRED]The type of tag on which to filter.
            value (string) -- [REQUIRED]A value for a tag key on which to filter.
            
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def describe_agents(agentIds=None, filters=None, maxResults=None, nextToken=None):
    """
    Lists agents or the Connector by ID or lists all agents/Connectors associated with your user account if you did not specify an ID.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_agents(
        agentIds=[
            'string',
        ],
        filters=[
            {
                'name': 'string',
                'values': [
                    'string',
                ],
                'condition': 'string'
            },
        ],
        maxResults=123,
        nextToken='string'
    )
    
    
    :type agentIds: list
    :param agentIds: The agent or the Connector IDs for which you want information. If you specify no IDs, the system returns information about all agents/Connectors associated with your AWS user account.
            (string) --
            

    :type filters: list
    :param filters: You can filter the request using various logical operators and a key -value format. For example:
            {'key': 'collectionStatus', 'value': 'STARTED'}
            (dict) --A filter that can use conditional operators.
            For more information about filters, see Querying Discovered Configuration Items .
            name (string) -- [REQUIRED]The name of the filter.
            values (list) -- [REQUIRED]A string value on which to filter. For example, if you choose the destinationServer.osVersion filter name, you could specify Ubuntu for the value.
            (string) --
            condition (string) -- [REQUIRED]A conditional operator. The following operators are valid: EQUALS, NOT_EQUALS, CONTAINS, NOT_CONTAINS. If you specify multiple filters, the system utilizes all filters as though concatenated by AND . If you specify multiple values for a particular filter, the system differentiates the values using OR . Calling either DescribeConfigurations or ListConfigurations returns attributes of matching configuration items.
            
            

    :type maxResults: integer
    :param maxResults: The total number of agents/Connectors to return in a single page of output. The maximum value is 100.

    :type nextToken: string
    :param nextToken: Token to retrieve the next set of results. For example, if you previously specified 100 IDs for DescribeAgentsRequest$agentIds but set DescribeAgentsRequest$maxResults to 10, you received a set of 10 results along with a token. Use that token in this query to get the next set of 10.

    :rtype: dict
    :return: {
        'agentsInfo': [
            {
                'agentId': 'string',
                'hostName': 'string',
                'agentNetworkInfoList': [
                    {
                        'ipAddress': 'string',
                        'macAddress': 'string'
                    },
                ],
                'connectorId': 'string',
                'version': 'string',
                'health': 'HEALTHY'|'UNHEALTHY'|'RUNNING'|'UNKNOWN'|'BLACKLISTED'|'SHUTDOWN',
                'lastHealthPingTime': 'string',
                'collectionStatus': 'string',
                'agentType': 'string',
                'registeredTime': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def describe_configurations(configurationIds=None):
    """
    Retrieves attributes for a list of configuration item IDs. All of the supplied IDs must be for the same asset type (server, application, process, or connection). Output fields are specific to the asset type selected. For example, the output for a server configuration item includes a list of attributes about the server, such as host name, operating system, and number of network cards.
    For a complete list of outputs for each asset type, see Using the DescribeConfigurations Action .
    See also: AWS API Documentation
    
    
    :example: response = client.describe_configurations(
        configurationIds=[
            'string',
        ]
    )
    
    
    :type configurationIds: list
    :param configurationIds: [REQUIRED]
            One or more configuration IDs.
            (string) --
            

    :rtype: dict
    :return: {
        'configurations': [
            {
                'string': 'string'
            },
        ]
    }
    
    
    :returns: 
    (dict) --
    (string) --
    (string) --
    
    
    
    
    
    """
    pass

def describe_export_configurations(exportIds=None, maxResults=None, nextToken=None):
    """
    Deprecated. Use DescribeExportTasks instead.
    Retrieves the status of a given export process. You can retrieve status from a maximum of 100 processes.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_export_configurations(
        exportIds=[
            'string',
        ],
        maxResults=123,
        nextToken='string'
    )
    
    
    :type exportIds: list
    :param exportIds: A unique identifier that you can use to query the export status.
            (string) --
            

    :type maxResults: integer
    :param maxResults: The maximum number of results that you want to display as a part of the query.

    :type nextToken: string
    :param nextToken: A token to get the next set of results. For example, if you specify 100 IDs for DescribeExportConfigurationsRequest$exportIds but set DescribeExportConfigurationsRequest$maxResults to 10, you get results in a set of 10. Use the token in the query to get the next set of 10.

    :rtype: dict
    :return: {
        'exportsInfo': [
            {
                'exportId': 'string',
                'exportStatus': 'FAILED'|'SUCCEEDED'|'IN_PROGRESS',
                'statusMessage': 'string',
                'configurationsDownloadUrl': 'string',
                'exportRequestTime': datetime(2015, 1, 1)
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def describe_export_tasks(exportIds=None, maxResults=None, nextToken=None):
    """
    Retrieve status of one or more export tasks. You can retrieve the status of up to 100 export tasks.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_export_tasks(
        exportIds=[
            'string',
        ],
        maxResults=123,
        nextToken='string'
    )
    
    
    :type exportIds: list
    :param exportIds: One or more unique identifiers used to query the status of an export request.
            (string) --
            

    :type maxResults: integer
    :param maxResults: The maximum number of volume results returned by DescribeExportTasks in paginated output. When this parameter is used, DescribeExportTasks only returns maxResults results in a single page along with a nextToken response element.

    :type nextToken: string
    :param nextToken: The nextToken value returned from a previous paginated DescribeExportTasks request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

    :rtype: dict
    :return: {
        'exportsInfo': [
            {
                'exportId': 'string',
                'exportStatus': 'FAILED'|'SUCCEEDED'|'IN_PROGRESS',
                'statusMessage': 'string',
                'configurationsDownloadUrl': 'string',
                'exportRequestTime': datetime(2015, 1, 1)
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def describe_tags(filters=None, maxResults=None, nextToken=None):
    """
    Retrieves a list of configuration items that are tagged with a specific tag. Or retrieves a list of all tags assigned to a specific configuration item.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_tags(
        filters=[
            {
                'name': 'string',
                'values': [
                    'string',
                ]
            },
        ],
        maxResults=123,
        nextToken='string'
    )
    
    
    :type filters: list
    :param filters: You can filter the list using a key -value format. You can separate these items by using logical operators. Allowed filters include tagKey , tagValue , and configurationId .
            (dict) --The tag filter. Valid names are: tagKey , tagValue , configurationId .
            name (string) -- [REQUIRED]A name of the tag filter.
            values (list) -- [REQUIRED]Values for the tag filter.
            (string) --
            
            

    :type maxResults: integer
    :param maxResults: The total number of items to return in a single page of output. The maximum value is 100.

    :type nextToken: string
    :param nextToken: A token to start the list. Use this token to get the next set of results.

    :rtype: dict
    :return: {
        'tags': [
            {
                'configurationType': 'SERVER'|'PROCESS'|'CONNECTION'|'APPLICATION',
                'configurationId': 'string',
                'key': 'string',
                'value': 'string',
                'timeOfCreation': datetime(2015, 1, 1)
            },
        ],
        'nextToken': 'string'
    }
    
    
    """
    pass

def disassociate_configuration_items_from_application(applicationConfigurationId=None, configurationIds=None):
    """
    Disassociates one or more configuration items from an application.
    See also: AWS API Documentation
    
    
    :example: response = client.disassociate_configuration_items_from_application(
        applicationConfigurationId='string',
        configurationIds=[
            'string',
        ]
    )
    
    
    :type applicationConfigurationId: string
    :param applicationConfigurationId: [REQUIRED]
            Configuration ID of an application from which each item is disassociated.
            

    :type configurationIds: list
    :param configurationIds: [REQUIRED]
            Configuration ID of each item to be disassociated from an application.
            (string) --
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def export_configurations():
    """
    Deprecated. Use StartExportTask instead.
    Exports all discovered configuration data to an Amazon S3 bucket or an application that enables you to view and evaluate the data. Data includes tags and tag associations, processes, connections, servers, and system performance. This API returns an export ID that you can query using the DescribeExportConfigurations API. The system imposes a limit of two configuration exports in six hours.
    See also: AWS API Documentation
    
    
    :example: response = client.export_configurations()
    
    
    :rtype: dict
    :return: {
        'exportId': 'string'
    }
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_discovery_summary():
    """
    Retrieves a short summary of discovered assets.
    See also: AWS API Documentation
    
    
    :example: response = client.get_discovery_summary()
    
    
    :rtype: dict
    :return: {
        'servers': 123,
        'applications': 123,
        'serversMappedToApplications': 123,
        'serversMappedtoTags': 123,
        'agentSummary': {
            'activeAgents': 123,
            'healthyAgents': 123,
            'blackListedAgents': 123,
            'shutdownAgents': 123,
            'unhealthyAgents': 123,
            'totalAgents': 123,
            'unknownAgents': 123
        },
        'connectorSummary': {
            'activeConnectors': 123,
            'healthyConnectors': 123,
            'blackListedConnectors': 123,
            'shutdownConnectors': 123,
            'unhealthyConnectors': 123,
            'totalConnectors': 123,
            'unknownConnectors': 123
        }
    }
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def list_configurations(configurationType=None, filters=None, maxResults=None, nextToken=None, orderBy=None):
    """
    Retrieves a list of configuration items according to criteria that you specify in a filter. The filter criteria identifies the relationship requirements.
    See also: AWS API Documentation
    
    
    :example: response = client.list_configurations(
        configurationType='SERVER'|'PROCESS'|'CONNECTION'|'APPLICATION',
        filters=[
            {
                'name': 'string',
                'values': [
                    'string',
                ],
                'condition': 'string'
            },
        ],
        maxResults=123,
        nextToken='string',
        orderBy=[
            {
                'fieldName': 'string',
                'sortOrder': 'ASC'|'DESC'
            },
        ]
    )
    
    
    :type configurationType: string
    :param configurationType: [REQUIRED]
            A valid configuration identified by Application Discovery Service.
            

    :type filters: list
    :param filters: You can filter the request using various logical operators and a key -value format. For example:
            {'key': 'serverType', 'value': 'webServer'}
            For a complete list of filter options and guidance about using them with this action, see Querying Discovered Configuration Items .
            (dict) --A filter that can use conditional operators.
            For more information about filters, see Querying Discovered Configuration Items .
            name (string) -- [REQUIRED]The name of the filter.
            values (list) -- [REQUIRED]A string value on which to filter. For example, if you choose the destinationServer.osVersion filter name, you could specify Ubuntu for the value.
            (string) --
            condition (string) -- [REQUIRED]A conditional operator. The following operators are valid: EQUALS, NOT_EQUALS, CONTAINS, NOT_CONTAINS. If you specify multiple filters, the system utilizes all filters as though concatenated by AND . If you specify multiple values for a particular filter, the system differentiates the values using OR . Calling either DescribeConfigurations or ListConfigurations returns attributes of matching configuration items.
            
            

    :type maxResults: integer
    :param maxResults: The total number of items to return. The maximum value is 100.

    :type nextToken: string
    :param nextToken: Token to retrieve the next set of results. For example, if a previous call to ListConfigurations returned 100 items, but you set ListConfigurationsRequest$maxResults to 10, you received a set of 10 results along with a token. Use that token in this query to get the next set of 10.

    :type orderBy: list
    :param orderBy: Certain filter criteria return output that can be sorted in ascending or descending order. For a list of output characteristics for each filter, see Using the ListConfigurations Action .
            (dict) --A field and direction for ordered output.
            fieldName (string) -- [REQUIRED]The field on which to order.
            sortOrder (string) --Ordering direction.
            
            

    :rtype: dict
    :return: {
        'configurations': [
            {
                'string': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    (dict) --
    (string) --
    (string) --
    
    
    
    
    
    """
    pass

def list_server_neighbors(configurationId=None, portInformationNeeded=None, neighborConfigurationIds=None, maxResults=None, nextToken=None):
    """
    Retrieves a list of servers that are one network hop away from a specified server.
    See also: AWS API Documentation
    
    
    :example: response = client.list_server_neighbors(
        configurationId='string',
        portInformationNeeded=True|False,
        neighborConfigurationIds=[
            'string',
        ],
        maxResults=123,
        nextToken='string'
    )
    
    
    :type configurationId: string
    :param configurationId: [REQUIRED]
            Configuration ID of the server for which neighbors are being listed.
            

    :type portInformationNeeded: boolean
    :param portInformationNeeded: Flag to indicate if port and protocol information is needed as part of the response.

    :type neighborConfigurationIds: list
    :param neighborConfigurationIds: List of configuration IDs to test for one-hop-away.
            (string) --
            

    :type maxResults: integer
    :param maxResults: Maximum number of results to return in a single page of output.

    :type nextToken: string
    :param nextToken: Token to retrieve the next set of results. For example, if you previously specified 100 IDs for ListServerNeighborsRequest$neighborConfigurationIds but set ListServerNeighborsRequest$maxResults to 10, you received a set of 10 results along with a token. Use that token in this query to get the next set of 10.

    :rtype: dict
    :return: {
        'neighbors': [
            {
                'sourceServerId': 'string',
                'destinationServerId': 'string',
                'destinationPort': 123,
                'transportProtocol': 'string',
                'connectionsCount': 123
            },
        ],
        'nextToken': 'string',
        'knownDependencyCount': 123
    }
    
    
    """
    pass

def start_data_collection_by_agent_ids(agentIds=None):
    """
    Instructs the specified agents or connectors to start collecting data.
    See also: AWS API Documentation
    
    
    :example: response = client.start_data_collection_by_agent_ids(
        agentIds=[
            'string',
        ]
    )
    
    
    :type agentIds: list
    :param agentIds: [REQUIRED]
            The IDs of the agents or connectors from which to start collecting data. If you send a request to an agent/connector ID that you do not have permission to contact, according to your AWS account, the service does not throw an exception. Instead, it returns the error in the Description field. If you send a request to multiple agents/connectors and you do not have permission to contact some of those agents/connectors, the system does not throw an exception. Instead, the system shows Failed in the Description field.
            (string) --
            

    :rtype: dict
    :return: {
        'agentsConfigurationStatus': [
            {
                'agentId': 'string',
                'operationSucceeded': True|False,
                'description': 'string'
            },
        ]
    }
    
    
    """
    pass

def start_export_task(exportDataFormat=None):
    """
    Export the configuration data about discovered configuration items and relationships to an S3 bucket in a specified format.
    See also: AWS API Documentation
    
    
    :example: response = client.start_export_task(
        exportDataFormat=[
            'CSV'|'GRAPHML',
        ]
    )
    
    
    :type exportDataFormat: list
    :param exportDataFormat: The file format for the returned export data. Default value is CSV .
            (string) --
            

    :rtype: dict
    :return: {
        'exportId': 'string'
    }
    
    
    """
    pass

def stop_data_collection_by_agent_ids(agentIds=None):
    """
    Instructs the specified agents or connectors to stop collecting data.
    See also: AWS API Documentation
    
    
    :example: response = client.stop_data_collection_by_agent_ids(
        agentIds=[
            'string',
        ]
    )
    
    
    :type agentIds: list
    :param agentIds: [REQUIRED]
            The IDs of the agents or connectors from which to stop collecting data.
            (string) --
            

    :rtype: dict
    :return: {
        'agentsConfigurationStatus': [
            {
                'agentId': 'string',
                'operationSucceeded': True|False,
                'description': 'string'
            },
        ]
    }
    
    
    """
    pass

def update_application(configurationId=None, name=None, description=None):
    """
    Updates metadata about an application.
    See also: AWS API Documentation
    
    
    :example: response = client.update_application(
        configurationId='string',
        name='string',
        description='string'
    )
    
    
    :type configurationId: string
    :param configurationId: [REQUIRED]
            Configuration ID of the application to be updated.
            

    :type name: string
    :param name: New name of the application to be updated.

    :type description: string
    :param description: New description of the application to be updated.

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

